@@ -5,12 +5,12 @@ import os
 import shutil
 import uuid
 
+import jinja2
 import ruamel.yaml
 import xapian
-import jinja2
+from pkg_resources import resource_filename, resource_string
 
-from pkg_resources import resource_string, resource_filename
-from . import types, templating
+from . import templating, types
 
 logger = logging.getLogger(__name__)
 
@@ -22,7 +22,7 @@ except ImportError:
     git_available = False
 
 
-class Entry(object):
+class Entry:
     def __init__(self, collection, data={}, fname=None):
         self.collection = collection
         self.data = data or self.empty_data()
@@ -152,7 +152,7 @@ class Entry(object):
             self.data[name] = field.auto(self.data.get(name, None))
 
 
-class Collection(object):
+class Collection:
     """
     """
 
@@ -297,7 +297,7 @@ class Collection(object):
         for fname in fnames:
             try:
                 valid, errors = self._index_file(fname, cache)
-            except IOError as e:
+            except OSError as e:
                 logger.warning(
                     "Could not load file {}: {}".format(fname, str(e))
                 )
