@@ -4,7 +4,6 @@ import unittest
 
 import lesana
 from lesana import types
-from . import utils
 
 
 class DerivedType(types.LesanaString):
@@ -22,16 +21,16 @@ class Derivative(lesana.Collection):
 
 class testDerivatives(unittest.TestCase):
     def setUp(self):
-        self.tmpdir = tempfile.mkdtemp()
-        utils.copytree(
+        self.tmpdir = tempfile.TemporaryDirectory()
+        shutil.copytree(
             'tests/data/derivative',
-            self.tmpdir,
+            self.tmpdir.name,
             dirs_exist_ok=True
         )
-        self.collection = Derivative(self.tmpdir)
+        self.collection = Derivative(self.tmpdir.name)
 
     def tearDown(self):
-        shutil.rmtree(self.tmpdir)
+        self.tmpdir.cleanup()
 
     def test_load_subclasses(self):
         self.assertIsInstance(self.collection.fields['unknown'], DerivedType)
